@@ -1,5 +1,5 @@
 /* auparse-defs.h --
- * Copyright 2006-07,09,2011-12 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2006-07,09,2011-12,2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -72,7 +72,7 @@ typedef enum {AUPARSE_CB_EVENT_READY} auparse_cb_event_t;
 
 /* This determines the type of field at current cursor location
  * ONLY APPEND - DO NOT DELETE or it will break ABI */
-enum {  AUPARSE_TYPE_UNCLASSIFIED,  AUPARSE_TYPE_UID, AUPARSE_TYPE_GID,
+typedef enum {  AUPARSE_TYPE_UNCLASSIFIED,  AUPARSE_TYPE_UID, AUPARSE_TYPE_GID,
 	AUPARSE_TYPE_SYSCALL, AUPARSE_TYPE_ARCH, AUPARSE_TYPE_EXIT,
 	AUPARSE_TYPE_ESCAPED, AUPARSE_TYPE_PERM, AUPARSE_TYPE_MODE,
 	AUPARSE_TYPE_SOCKADDR, AUPARSE_TYPE_FLAGS, AUPARSE_TYPE_PROMISC,
@@ -83,7 +83,7 @@ enum {  AUPARSE_TYPE_UNCLASSIFIED,  AUPARSE_TYPE_UID, AUPARSE_TYPE_GID,
 	AUPARSE_TYPE_ICMPTYPE, AUPARSE_TYPE_PROTOCOL,
 	AUPARSE_TYPE_ADDR, AUPARSE_TYPE_PERSONALITY,
 	AUPARSE_TYPE_SECCOMP, AUPARSE_TYPE_OFLAG,
-	AUPARSE_TYPE_MMAP, AUPARSE_TYPE_MODE_SHORT } auparse_type_t;
+	AUPARSE_TYPE_MMAP, AUPARSE_TYPE_MODE_SHORT, AUPARSE_TYPE_MAC_LABEL  } auparse_type_t;
 
 #ifdef __cplusplus
 }
