@@ -1,6 +1,6 @@
 /*
 * interpret.c - Lookup values to something more readable
-* Copyright (c) 2007-09,2011-13 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2007-09,2011-14 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved. 
 *
 * This software may be freely redistributed and/or modified under the
@@ -49,6 +49,7 @@
 #include <linux/capability.h>
 #include <sys/personality.h>
 #include <sys/prctl.h>
+#include <sched.h>
 #include "auparse-defs.h"
 #include "gen_tables.h"
 
@@ -364,6 +365,54 @@ static const char *print_arch(const char *val, unsigned int machine)
 	}
 }
 
+static const char *print_ipccall(const char *val, unsigned int base)
+{
+	int a0;
+	char *out;
+	const char *func = NULL;
+
+	errno = 0;
+	a0 = strtol(val, NULL, base);
+	if (errno) {
+		char *out;
+		if (asprintf(&out, "conversion error(%s)", val) < 0)
+			out = NULL;
+		return out;
+	}
+	func = ipc_i2s(a0);
+	if (func)
+		return strdup(func);
+	else {
+		if (asprintf(&out, "unknown ipccall(%d)", val) < 0)
+			out = NULL;
+                return out;
+	}
+}
+
+static const char *print_socketcall(const char *val, unsigned int base)
+{
+	int a0;
+	char *out;
+	const char *func = NULL;
+
+	errno = 0;
+	a0 = strtol(val, NULL, base);
+	if (errno) {
+		char *out;
+		if (asprintf(&out, "conversion error(%s)", val) < 0)
+			out = NULL;
+		return out;
+	}
+	func = sock_i2s(a0);
+	if (func)
+		return strdup(func);
+	else {
+		if (asprintf(&out, "unknown socketcall(%d)", val) < 0)
+			out = NULL;
+                return out;
+	}
+}
+
 static const char *print_syscall(const char *val, const idata *id)
 {
         const char *sys;
@@ -401,11 +450,11 @@ static const char *print_syscall(const char *val, const idata *id)
 
 static const char *print_exit(const char *val)
 {
-        int ival;
-	char *out;
+        long long ival;
+        char *out;
 
         errno = 0;
-        ival = strtol(val, NULL, 10);
+        ival = strtoll(val, NULL, 10);
         if (errno) {
 		if (asprintf(&out, "conversion error(%s)", val) < 0)
 			out = NULL;
@@ -413,12 +462,11 @@ static const char *print_exit(const char *val)
         }
 
         if (ival < 0) {
-		if (asprintf(&out, "%d(%s)", ival, strerror(-ival)) < 0)
+		if (asprintf(&out, "%lld(%s)", ival, strerror(-ival)) < 0)
 			out = NULL;
 		return out;
         }
         return strdup(val);
-
 }
 
 static const char *print_escaped(const char *val)
@@ -670,6 +718,7 @@ static const char *print_sockaddr(const char *val)
         if (str == NULL) {
 		if (asprintf(&out, "unknown family(%d)", saddr->sa_family) < 0)
 			out = NULL;
+		free((char *)host);
 		return out;
 	}
 
@@ -1348,9 +1397,12 @@ static char *print_dirfd(const char *val)
 	return out;
 }
 
+#ifndef SCHED_RESET_ON_FORK
+#define SCHED_RESET_ON_FORK 0x40000000
+#endif
 static const char *print_sched(const char *val)
 {
-        int pol;
+        unsigned int pol;
         char *out;
         const char *s;
 
@@ -1362,9 +1414,15 @@ static const char *print_sched(const char *val)
                 return out;
         }
 
-	s = sched_i2s(pol);
-	if (s != NULL)
-		return strdup(s);
+	s = sched_i2s(pol & 0x0F);
+	if (s != NULL) {
+		char buf[48];
+
+		strcpy(buf, s);
+		if (pol & SCHED_RESET_ON_FORK )
+			strcat(buf, "|SCHED_RESET_ON_FORK");
+		return strdup(buf);
+	}
 	if (asprintf(&out, "unknown scheduler policy (0x%s)", val) < 0)
 		out = NULL;
 	return out;
@@ -1718,6 +1776,8 @@ static const char *print_a0(const char *val, const idata *id)
 				return print_socket_domain(val);
                 	else if (strcmp(sys, "setfsgid") == 0)
 				return print_gid(val, 16);
+                	else if (strcmp(sys, "socketcall") == 0)
+				return print_socketcall(val, 16);
 		}
 		else if (strcmp(sys, "linkat") == 0)
 			return print_dirfd(val);
@@ -1725,6 +1785,8 @@ static const char *print_a0(const char *val, const idata *id)
 			return print_dirfd(val);
 		else if (strcmp(sys, "openat") == 0)
 			return print_dirfd(val);
+               	else if (strcmp(sys, "ipccall") == 0)
+			return print_ipccall(val, 16);
 	}
 	if (asprintf(&out, "0x%s", val) < 0)
 			out = NULL;
@@ -2266,6 +2328,8 @@ int auparse_interp_adjust_type(int rtype, const char *name, const char *val)
 		type = AUPARSE_TYPE_FLAGS;
 	else if (rtype == AUDIT_MQ_OPEN && strcmp(name, "mode") == 0)
 		type = AUPARSE_TYPE_MODE_SHORT;
+	else if (rtype == AUDIT_CRYPTO_KEY_USER && strcmp(name, "fp") == 0)
+		type = AUPARSE_TYPE_UNCLASSIFIED;
 	else
 		type = lookup_type(name);
 
@@ -2370,6 +2434,7 @@ const char *auparse_do_interpretation(int type, const idata *id)
 		case AUPARSE_TYPE_MMAP:
 			out = print_mmap(id->val);
 			break;
+		case AUPARSE_TYPE_MAC_LABEL:
 		case AUPARSE_TYPE_UNCLASSIFIED:
 		default:
 			out = strdup(id->val);
