@@ -1,5 +1,5 @@
 /* aarch64_table.h --
- * Copyright 2013 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2013,2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -45,6 +45,7 @@ _S(21, "epoll_ctl")
 _S(22, "epoll_pwait")
 _S(23, "dup")
 _S(24, "dup3")
+_S(25, "fcntl")
 _S(26, "inotify_init1")
 _S(27, "inotify_add_watch")
 _S(28, "inotify_rm_watch")
@@ -62,6 +63,10 @@ _S(39, "umount2")
 _S(40, "mount")
 _S(41, "pivot_root")
 _S(42, "nfsservctl")
+_S(43, "statfs")
+_S(44, "fstatfs")
+_S(45, "truncate")
+_S(46, "ftruncate")
 _S(47, "fallocate")
 _S(48, "faccessat")
 _S(49, "chdir")
@@ -76,15 +81,17 @@ _S(57, "close")
 _S(58, "vhangup")
 _S(59, "pipe2")
 _S(60, "quotactl")
-_S(61, "getdents64")
+_S(61, "getdents")
+_S(62, "lseek")
 _S(63, "read")
 _S(64, "write")
 _S(65, "readv")
 _S(66, "writev")
-_S(67, "pread64")
-_S(68, "pwrite64")
+_S(67, "pread")
+_S(68, "pwrite")
 _S(69, "preadv")
 _S(70, "pwritev")
+_S(71, "sendfile")
 _S(72, "pselect6")
 _S(73, "ppoll")
 _S(74, "signalfd4")
@@ -92,6 +99,8 @@ _S(75, "vmsplice")
 _S(76, "splice")
 _S(77, "tee")
 _S(78, "readlinkat")
+_S(79, "newfstatat")
+_S(80, "newfstat")
 _S(81, "sync")
 _S(82, "fsync")
 _S(83, "fdatasync")
@@ -233,6 +242,8 @@ _S(218, "request_key")
 _S(219, "keyctl")
 _S(220, "clone")
 _S(221, "execve")
+_S(222, "mmap")
+_S(223, "fadvise64")
 _S(224, "swapon")
 _S(225, "swapoff")
 _S(226, "mprotect")
@@ -267,3 +278,6 @@ _S(270, "process_vm_readv")
 _S(271, "process_vm_writev")
 _S(272, "kcmp")
 _S(273, "finit_module")
+_S(274, "sched_setattr")
+_S(275, "sched_getattr")
+_S(276, "renameat2")
