@@ -1,5 +1,5 @@
 /* libaudit.c -- 
- * Copyright 2004-2009,2012 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2004-2009,2012,2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -493,6 +493,61 @@ int audit_set_backlog_limit(int fd, uint32_t limit)
 	return rc;
 }
 
+int audit_set_feature(int fd, unsigned feature, unsigned value, unsigned lock)
+{
+#if HAVE_DECL_AUDIT_FEATURE_VERSION
+	int rc;
+	struct audit_features f;
+
+	memset(&f, 0, sizeof(f));
+	f.mask = AUDIT_FEATURE_TO_MASK(feature);
+	if (value)
+		f.features = AUDIT_FEATURE_TO_MASK(feature);
+	if (lock)
+		f.lock = AUDIT_FEATURE_TO_MASK(feature);
+	rc = audit_send(fd, AUDIT_SET_FEATURE, &f, sizeof(f));
+	if (rc < 0)
+		audit_msg(audit_priority(errno),
+			"Error setting feature (%s)", 
+			strerror(-rc));
+	return rc;
+#else
+	errno = EINVAL;
+	return -1;
+#endif
+}
+hidden_def(audit_set_feature)
+
+int audit_request_features(int fd)
+{
+#if HAVE_DECL_AUDIT_FEATURE_VERSION
+	int rc;
+	struct audit_features f;
+
+	memset(&f, 0, sizeof(f));
+	rc = audit_send(fd, AUDIT_GET_FEATURE, &f, sizeof(f));
+	if (rc < 0)
+		audit_msg(audit_priority(errno),
+			"Error getting feature (%s)", 
+			strerror(-rc));
+	return rc;
+#else
+	errno = EINVAL;
+	return -1;
+#endif
+}
+hidden_def(audit_request_features)
+
+extern int  audit_set_loginuid_immutable(int fd)
+{
+#if HAVE_DECL_AUDIT_FEATURE_VERSION
+	return audit_set_feature(fd, AUDIT_FEATURE_LOGINUID_IMMUTABLE, 1, 1);
+#else
+	errno = EINVAL;
+	return -1;
+#endif
+}
+
 int audit_request_rules_list_data(int fd)
 {
 	int rc = audit_send(fd, AUDIT_LIST_RULES, NULL, 0);
@@ -1081,9 +1136,18 @@ int audit_determine_machine(const char *arch)
 	} else if (strcasecmp("b32", arch) == 0) {
 		bits = ~__AUDIT_ARCH_64BIT;
 		machine = audit_detect_machine();
-	} 
-	else 
+	} else { 
 		machine = audit_name_to_machine(arch);
+		if (machine < 0) {
+			// See if its numeric
+			unsigned int ival;
+			errno = 0;
+			ival = strtoul(arch, NULL, 16);
+			if (errno)
+				return -4;
+			machine = audit_elf_to_machine(ival);
+		}
+	}
 
 	if (machine < 0) 
 		return -4;
