@@ -1,5 +1,5 @@
 /* aureport-options.c - parse commandline options and configure aureport
- * Copyright 2005-08,2010-11 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-08,2010-11,2014 Red Hat Inc., Durham, North Carolina.
  * Copyright (c) 2011 IBM Corp.
  * All Rights Reserved.
  *
@@ -39,9 +39,12 @@
 /* Global vars that will be accessed by the main program */
 char *user_file = NULL;
 int force_logs = 0;
+int no_config = 0;
 
 /* These are for compatibility with parser */
 unsigned int event_id = -1;
+uid_t event_uid = -1, event_loginuid = -2, event_euid = -1;
+gid_t event_gid = -1, event_egid = -1;
 slist *event_node_list = NULL;
 const char *event_key = NULL;
 const char *event_filename = NULL;
@@ -53,8 +56,10 @@ const char *event_subject = NULL;
 const char *event_object = NULL;
 const char *event_uuid = NULL;
 const char *event_vmname = NULL;
-int event_exit = 0, event_exit_is_set = 0;
+long long event_exit = 0;
+int event_exit_is_set = 0;
 int event_ppid = -1, event_session_id = -2;
+int event_debug = 0, event_machine = -1;
 
 /* These are used by aureport */
 const char *dummy = "dummy";
@@ -76,7 +81,7 @@ enum {  R_INFILE, R_TIME_END, R_TIME_START, R_VERSION, R_SUMMARY, R_LOG_TIMES,
 	R_AVCS, R_SYSCALLS, R_PIDS, R_EVENTS, R_ACCT_MODS,  
 	R_INTERPRET, R_HELP, R_ANOMALY, R_RESPONSE, R_SUMMARY_DET, R_CRYPTO,
 	R_MAC, R_FAILED, R_SUCCESS, R_ADD, R_DEL, R_AUTH, R_NODE, R_IN_LOGS,
-	R_KEYS, R_TTY };
+	R_KEYS, R_TTY, R_NO_CONFIG };
 
 static struct nv_pair optiontab[] = {
 	{ R_AUTH, "-au" },
@@ -111,6 +116,8 @@ static struct nv_pair optiontab[] = {
 	{ R_MAC, "-ma" },
 	{ R_MAC, "--mac" },
 	{ R_NODE, "--node" },
+	{ R_NO_CONFIG, "-nc" },
+	{ R_NO_CONFIG, "--no-config" },
 	{ R_ANOMALY, "-n" },
 	{ R_ANOMALY, "--anomaly" },
 	{ R_PIDS, "-p" },
@@ -169,8 +176,9 @@ static void usage(void)
 	"\t-k,--key\t\t\tKey report\n"
 	"\t-m,--mods\t\t\tModification to accounts report\n"
 	"\t-ma,--mac\t\t\tMandatory Access Control (MAC) report\n"
-	"\t--node <node name>\t\tOnly events from a specific node\n"
 	"\t-n,--anomaly\t\t\taNomaly report\n"
+	"\t-nc,--no-config\t\t\tDon't include config events\n"
+	"\t--node <node name>\t\tOnly events from a specific node\n"
 	"\t-p,--pid\t\t\tPid report\n"
 	"\t-r,--response\t\t\tResponse to anomaly report\n"
 	"\t-s,--syscall\t\t\tSyscall report\n"
@@ -270,25 +278,32 @@ int check_params(int count, char *vars[])
 				event_exe = dummy;
 				event_hostname = dummy;
 				event_terminal = dummy;
+				event_uid = 1;
 			}
 			break;
 		case R_MAC:
 			if (set_report(RPT_MAC))
 				retval = -1;
-			else 
+			else { 
 				set_detail(D_DETAILED);
+				event_loginuid = 1;
+			}
 			break;
 		case R_CONFIGS:
 			if (set_report(RPT_CONFIG))
 				retval = -1;
-			else 
+			else { 
 				set_detail(D_DETAILED);
+				event_loginuid = 1;
+			}
 			break;
 		case R_CRYPTO:
 			if (set_report(RPT_CRYPTO))
 				retval = -1;
-			else 
+			else { 
 				set_detail(D_DETAILED);
+				event_loginuid = 1;
+			}
 			break;
 		case R_LOGINS:
 			if (set_report(RPT_LOGIN))
@@ -298,6 +313,7 @@ int check_params(int count, char *vars[])
 				event_exe = dummy;
 				event_hostname = dummy;
 				event_terminal = dummy;
+				event_uid = 1;
 			}
 			break;
 		case R_ACCT_MODS:
@@ -308,15 +324,17 @@ int check_params(int count, char *vars[])
 				event_exe = dummy;
 				event_hostname = dummy;
 				event_terminal = dummy;
+				event_loginuid = 1;
 			}
 			break;
 		case R_EVENTS:
 			if (set_report(RPT_EVENT))
 				retval = -1;
 			else {
-//				if (!optarg)
+//				if (!optarg) {
 					set_detail(D_DETAILED);
-//				else {
+					event_loginuid = 1;
+//				} else {
 //					UNIMPLEMENTED;
 //					set_detail(D_SPECIFIC);
 //					if (isdigit(optarg[0])) {
@@ -346,6 +364,7 @@ int check_params(int count, char *vars[])
 					set_detail(D_DETAILED);
 					event_filename = dummy;
 					event_exe = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -358,6 +377,7 @@ int check_params(int count, char *vars[])
 				if (!optarg) {
 					set_detail(D_DETAILED);
 					event_hostname = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -379,6 +399,7 @@ int check_params(int count, char *vars[])
 				if (!optarg) {
 					set_detail(D_DETAILED);
 					event_exe = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -391,6 +412,7 @@ int check_params(int count, char *vars[])
 				if (!optarg) {
 					set_detail(D_DETAILED);
 					event_comm = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -405,6 +427,7 @@ int check_params(int count, char *vars[])
 					event_terminal = dummy;
 					event_hostname = dummy;
 					event_exe = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -419,6 +442,8 @@ int check_params(int count, char *vars[])
 					event_terminal = dummy;
 					event_hostname = dummy;
 					event_exe = dummy;
+					event_uid = 1;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -433,6 +458,7 @@ int check_params(int count, char *vars[])
 					event_terminal = dummy;
 					event_hostname = dummy;
 					event_exe = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -448,6 +474,7 @@ int check_params(int count, char *vars[])
 					event_hostname = dummy;
 					event_exe = dummy;
 					event_comm = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -472,6 +499,7 @@ int check_params(int count, char *vars[])
 					set_detail(D_DETAILED);
 					event_exe = dummy;
 					event_key = dummy;
+					event_loginuid = 1;
 				} else {
 					UNIMPLEMENTED;
 				}
@@ -481,10 +509,11 @@ int check_params(int count, char *vars[])
 			if (set_report(RPT_TTY))
 				retval = -1;
 			else {
+				set_detail(D_DETAILED);
 				event_session_id = 1;
+				event_loginuid = 1;
 				event_terminal = dummy;
 				event_comm = dummy;
-				set_detail(D_DETAILED);
 			}
 			break;
 		case R_TIME_END:
@@ -614,6 +643,9 @@ int check_params(int count, char *vars[])
 		case R_IN_LOGS:
 			force_logs = 1;
 			break;
+		case R_NO_CONFIG:
+			no_config = 1;
+			break;
 		case R_VERSION:
 	                printf("aureport version %s\n", VERSION);
 			exit(0);
@@ -642,6 +674,7 @@ int check_params(int count, char *vars[])
 				event_terminal = dummy;
 				event_exe = dummy;
 				event_key = dummy;
+				event_loginuid = 1;
 			}
 		}
 	} else
