@@ -140,7 +140,7 @@ static void output_interpreted(llist *l)
 static void output_interpreted_node(const lnode *n)
 {
 	char *ptr, *str = n->message, *node = NULL;
-	int found;
+	int found, comma = 0;
 
 	// Reset these because each record could be different
 	machine = -1;
@@ -241,7 +241,7 @@ no_print:
 	found = 0;
 	while (str && *str && (ptr = strchr(str, '='))) {
 		char *name, *val;
-		int comma = 0;
+		comma = 0;
 		found = 1;
 
 		// look back to last space - this is name
@@ -276,12 +276,32 @@ no_print:
 			str = strchr(ptr, ',');
 			val = strchr(ptr, ' ');
 			if (str && val && (str < val)) {
-				*str++ = 0;
-				comma = 1;
+			// Value side  has commas and another field exists
+			// Known: LABEL_LEVEL_CHANGE banners=none,none
+			// Known: ROLL_ASSIGN new-role=r,r
+			// Known: any MAC LABEL can potentially have commas
+				int ftype = auparse_interp_adjust_type(n->type,
+								name, val);
+				if (ftype == AUPARSE_TYPE_MAC_LABEL) {
+					str = val;
+					*str++ = 0;
+				} else {
+					*str++ = 0;
+					comma = 1;
+				}
 			} else if (str && (val == NULL)) {
-				*str++ = 0;
-				comma = 1;
+			// Goes all the way to the end. Done parsing
+			// Known: MCS context in PATH rec obj=u:r:t:s0:c2,c7
+				int ftype = auparse_interp_adjust_type(n->type,
+								name, ptr);
+				if (ftype == AUPARSE_TYPE_MAC_LABEL)
+					str = NULL;
+				else {
+					*str++ = 0;
+					comma = 1;
+				}
 			} else if (val) {
+			// There is another field, point to next (normal path)
 				str = val;
 				*str++ = 0;
 			}
@@ -295,6 +315,9 @@ no_print:
 	// If nothing found, just print out as is
 	if (!found && ptr == NULL && str)
 		printf("%s", str);
+	// If last field had comma, output the rest
+	else if (comma)
+		printf("%s", str);
 	printf("\n");
 }
 
@@ -314,7 +337,7 @@ static void interpret(char *name, char *val, int comma, int rtype)
 	}
 	type = auparse_interp_adjust_type(rtype, name, val);
 
-	if (rtype == AUDIT_SYSCALL) {
+	if (rtype == AUDIT_SYSCALL || rtype == AUDIT_SECCOMP) {
 		if (machine == (unsigned long)-1) 
 			machine = audit_detect_machine();
 		if (*name == 'a' && strcmp(name, "arch") == 0) {
